import request from "../../request.js"

// 根据被护理人id查询基本信息
export function goodPatientInfo(patientId) {
	return request({
		url: `/nurseApplet/nursingStationGoods/goodPatientInfo?patientId=${patientId}`,
		method: 'GET',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}
// 新增基本信息
export function addnursingStation(data) {
	return request({
		url: '/nurseApplet/nursingStationGoods/add',
		method: 'POST',
		data,
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}

// 修改基本信息

export function updatenursingStation(data) {
	return request({
		url: '/nurseApplet/nursingStationGoods/edit',
		method: 'POST',
		data,
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}
// 修改反显
export function nursingStationGoodsinfo(id) {
	return request({
		url: '/nurseApplet/nursingStationGoods/' + id,
		method: 'GET',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}

// 删除
export function delnursingStation(id) {
	return request({
		url: '/nurseApplet/nursingStationGoods/' + id,
		method: 'delete',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}
// 查询
export function getSubordinate(areaCode) {
	return request({
		url: `/nurseApplet/nursingStationGoods/getSubordinateRegions?areaCode=${areaCode}`,
		method: 'GET',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}
// //区街道list
// export function getSubordinateRegions(areaCode) {
// 	return request({
// 		url: `/nurseApplet/nursingStationGoods/getSubordinateRegions?areaCode=${areaCode}`,
// 		method: 'GET'
// 	})
// }
//省list
export function getSubordinateRegions(areaCode) {
	return request({
		url: `/nurseApplet/login/getProvinceInfo?areaCode=${areaCode}`,
		method: 'GET',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}
//市区街道list
export function getSubordinateInfo(id) {
	return request({
		url: `/nurseApplet/login/getSubordinateInfo?areaCode=${id}`,
		method: 'GET',
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}

//默认地址

export function updateDefaultAddress(data) {
	return request({
		url: `/nurseApplet/nursingStationGoods/updateDefaultAddress`,
		method: 'POST',
		data,
		header: {
			Authorization: 'Bearer' + ' ' + uni.getStorageSync('token')
		},
	})
}